draw method

Widget draw(
  1. BuildContext context,
  2. WalletGlyph glyph, {
  3. double? size,
  4. Color? color,
  5. String? semanticLabel,
})

glyph drawn by the host's builder, or as its Material default when the host has none or does not map it.

Implementation

Widget draw(
  BuildContext context,
  WalletGlyph glyph, {
  double? size,
  Color? color,
  String? semanticLabel,
}) =>
    builder?.call(
      context,
      glyph,
      size: size,
      color: color,
      semanticLabel: semanticLabel,
    ) ??
    Icon(
      glyph.material,
      size: size,
      color: color,
      semanticLabel: semanticLabel,
    );