SendSignFailed class

Build/sign failed — no money moved. "Couldn't complete this payment; nothing was sent." The user re-proposes (the consumed token can't be re-sent).

Inheritance

Constructors

SendSignFailed()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited