SendSubmitting class

send in flight (sign in a blocking proving task + persist + broadcast). Transient; a spinner. Holds the proposal so a UI can keep showing the figures.

Inheritance

Constructors

SendSubmitting(SendProposal proposal)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
proposal → SendProposal
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited