motion property
Whether funds have left the shielded pool onto a wallet-controlled one-time address without confirming at the recipient — see WalletSendMotion, and note it is THREE-valued for a reason.
Implementation
final WalletSendMotion motion;
Whether funds have left the shielded pool onto a wallet-controlled one-time address without confirming at the recipient — see WalletSendMotion, and note it is THREE-valued for a reason.
final WalletSendMotion motion;