ZecAmountValid class

A valid, positive, in-range amount in zatoshis.

Inheritance

Constructors

ZecAmountValid(int zat)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zat → int
Amount in zatoshis (exact; 1 <= zat <= maxMoneyZat).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited