ShieldDone class

Terminal result of the shield's send — the reused SendOutcome (the shield IS a send of the retained token, 3.3a Recv-3).

Inheritance

Constructors

ShieldDone(SendOutcome outcome)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
outcome → SendOutcome
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited