walletDeepScanRestoreNoteBody property

String get walletDeepScanRestoreNoteBody

#390 one-time post-restore note body — educates that the situation can happen and how to resolve it, without alarming (‘most wallets need nothing’).

In en, this message translates to: 'If this wallet had a very long swap history, money from its oldest swaps can take an extra step to find. Most wallets need nothing.'

Implementation

String get walletDeepScanRestoreNoteBody;