WalletCtaSize enum

Where a call to action sits, which decides its height floor.

Inheritance
Available extensions

Values

page → const WalletCtaSize

A page's primary action: at least 56 tall.

sheet → const WalletCtaSize

A sheet's primary action: at least 52 tall.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<WalletCtaSize>
A constant List of the values in this enum, in order of their declaration.