rowInset constant
double
const rowInset
The inset of a row with no leading glyph (its 16 padding).
Implementation
static const double rowInset = 16;
The inset of a row with no leading glyph (its 16 padding).
static const double rowInset = 16;