exists property
What walletExists reports (the on-disk fork). Mutable so a test can flip it (e.g. create makes a wallet exist for a later resume).
Implementation
bool exists;
What walletExists reports (the on-disk fork). Mutable so a test can flip it (e.g. create makes a wallet exist for a later resume).
bool exists;