push method
void
push(
- SyncStatus status
Push a new live status to the active subscription (and make it the value a later subscribe replays).
Implementation
void push(SyncStatus status) {
_current = status;
_active?.add(status);
}