SendForm class
The editable send form. fault is an inline, honest message from a failed
prepare/queue (a bad address, not enough funds, …) — null on first entry.
Constructors
- SendForm({SendFormFault? fault})
-
const
Properties
- fault → SendFormFault?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited