WalletSendTransactionCreated constructor
WalletSendTransactionCreated({})
Implementation
WalletSendTransactionCreated({
required this.txids,
required this.broadcastCount,
required this.motion,
this.recipientAmountZat,
super.correlationId,
}) : assert(
txids.isNotEmpty,
'a transaction-exists report with no id is not this variant — it is '
'WalletSendUnclassified (a host cannot reconcile a payment it cannot '
'cite)',
),
assert(
broadcastCount >= 0 && broadcastCount <= txids.length,
'broadcastCount counts a subset of txids',
);