purposeMaxChars constant
int
const purposeMaxChars
The bound on purpose. It is rendered on a money surface at any text scale, so it is a sentence, not a payload.
Implementation
static const purposeMaxChars = 140;