ShieldSubmitting class
send (sign + broadcast the shield tx) in flight. Transient; a spinner. Holds
the proposal so the sheet can keep showing the figures.
- Inheritance
-
- Object
- ShieldState
- ShieldSubmitting
Constructors
- ShieldSubmitting(SendProposal proposal)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- proposal → SendProposal
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited