DeepScanRestoreNoteController class
Constructors
Properties
-
future
→ Future<
DeepScanRestoreNoteState> -
Obtains a Future that resolves with the first
statevalue that is notAsyncLoading.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
The
Refassociated with this notifier.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ AsyncValue<
DeepScanRestoreNoteState> -
The value currently exposed by this notifier.
getter/setter pairinherited
Methods
-
acknowledge(
) → Future< void> -
The user checked or dismissed the note — record
doneso it never returns (durably, across relaunch). Optimistically hides it first; a failed write is non-fatal (the store setter never throws). -
build(
) → Future< DeepScanRestoreNoteState> -
Initialize an
AsyncNotifier. -
listenSelf(
void listener(AsyncValue< DeepScanRestoreNoteState> ? previous, AsyncValue<DeepScanRestoreNoteState> next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runBuild(
) → WhenComplete? -
Executes
Notifier.build.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
update(
FutureOr< DeepScanRestoreNoteState> cb(DeepScanRestoreNoteState previousState), {FutureOr<DeepScanRestoreNoteState> onError(Object err, StackTrace stackTrace)?}) → Future<DeepScanRestoreNoteState> -
A function to update
statefrom its previous value, while abstracting loading/error cases forstate.inherited -
updateShouldNotify(
AsyncValue< DeepScanRestoreNoteState> previous, AsyncValue<DeepScanRestoreNoteState> next) → bool -
A method invoked when the state exposed by this
Notifierchanges. It compares the previous and new value, and return whether listeners should be notified.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited