walletSyncServerFallbackNotOffered abstract method
Banner on the sync sheet's Server row and the picker when the REMEMBERED choice names a server this app version no longer offers (SyncServerFallback.choiceNotOffered): the default is in use, said, never silent. host = the server now in use.
In en, this message translates to: 'The server you chose isn't offered by this app any more. Using {host}.'
Implementation
String walletSyncServerFallbackNotOffered(String host);