messageInTone property
The line only: draw the message in the tone colour too (the transparent arm of the privacy statement, whose words are the warning).
Implementation
final bool messageInTone;
The line only: draw the message in the tone colour too (the transparent arm of the privacy statement, whose words are the warning).
final bool messageInTone;