pushSwap method

void pushSwap(
  1. SwapStatus status
)

Push a new live swap status to the active subscription (and make it the value a later subscribe replays).

Implementation

void pushSwap(SwapStatus status) {
  swapCurrent = status;
  _activeSwap?.add(status);
}